@@ -6,7 +6,7 @@ def add_default_arguments(parser: argparse.ArgumentParser) -> None:
     parser.add_argument( '--directory', '-d', type=str,
         metavar='DIR',
         default='',
-        help="directory of Kindfile (default is current working directory)", required=False)
+        help="directory of kindfile.yaml (default is current working directory)", required=False)
 
 def main_parser() -> argparse.ArgumentParser:
     parser = argparse.ArgumentParser(prog=__app_name__)
@@ -16,7 +16,7 @@ def main_parser() -> argparse.ArgumentParser:
 
 def create_parser_init(parent: argparse.ArgumentParser) -> None:
     name = 'init'
-    help = 'create a new Kindfile'
+    help = 'create a new kindfile.yaml'
 
     parser = parent.add_parser(name, help=help)
     parser.add_argument( '--directory', '-d', type=str,
@@ -138,6 +138,13 @@ def create_parser_get_mountpoints(parent: argparse.ArgumentParser) -> None:
     parser = parent.add_parser(name, help=help)
     add_default_arguments(parser)
 
+def create_parser_get_api_server_address(parent: argparse.ArgumentParser) -> None:
+    name = 'api_server_address'
+    help = 'returns the ip address of the k8s API server'
+
+    parser = parent.add_parser(name, help=help)
+    add_default_arguments(parser)
+
 def create_parser_get_internal_registry_prefix(parent: argparse.ArgumentParser) -> None:
     name = 'internal_registry_prefix'
     help = 'returns the prefix internal docker registry if internal_registry is enabled'
@@ -166,6 +173,7 @@ def main() -> None:
     create_parser_get_ingress_https_port(subparser)
     create_parser_get_metallb(subparser)
     create_parser_get_mountpoints(subparser)
+    create_parser_get_api_server_address(subparser)
     create_parser_get_internal_registry_prefix(subparser)
 
     args = parser.parse_args()
@@ -201,6 +209,7 @@ def main() -> None:
             'ingress', 'ingress_http_port', 'ingress_https_port',
             'metallb',
             'mountpoints',
+            'api_server_address',
             'internal_registry_prefix'
         ]
         if args.get in arr:
